@@ -2,7 +2,6 @@ package Pcore::Handle::xmpp;
 
 use Pcore -class;
 use Net::XMPP;
-use Mozilla::CA;
 
 with qw[Pcore::Handle::Wrapper];
 
@@ -19,7 +18,7 @@ sub _connect ($self) {
         componentname  => $uri->host->name,
         connectiontype => 'tcpip',
         tls            => 1,
-        ssl_ca_path    => Mozilla::CA::SSL_ca_file(),
+        ssl_ca_path    => P->ca->ca_file,
     );
 
     die 'XMPP connection error' unless $h->Connected;
@@ -57,8 +56,8 @@ sub sendmsg ( $self, $to, $msg ) {
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
 ## |    3 |                      | Subroutines::ProhibitUnusedPrivateSubroutines                                                                  |
-## |      | 9                    | * Private subroutine/method '_connect' declared but not used                                                   |
-## |      | 40                   | * Private subroutine/method '_disconnect' declared but not used                                                |
+## |      | 8                    | * Private subroutine/method '_connect' declared but not used                                                   |
+## |      | 39                   | * Private subroutine/method '_disconnect' declared but not used                                                |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
